/* Copyright 2008 Daniel Vokó <vokoda@gmail.com>
 * 
 * This file is part of Sagittarius.
 *
 * Sagittarius is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * Sagittarius is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Sagittarius.  If not, see <http://www.gnu.org/licenses/>.
 */


using System;
using System.Collections.Generic;

namespace Sagittarius.Metadata
{
	/// <summary>
	/// A key-value pair of strings 
	/// with public properties for acessing and setting
	/// </summary>
	public class MetadataElement : IComparable<MetadataElement>
	{
		public MetadataElement(string mKey, string mValue)
		{
			this.mKey = mKey;
			this.mValue = mValue;
			changed = false;
		}
		
		private string mKey;
		private string mValue;
		private bool changed;

		public int CompareTo(MetadataElement rhs)
		{
			return this.Key.CompareTo(rhs.Key);
		}
		
		public string Key 
		{
			get { return mKey; }
			//set {  mKey = value; }
		}
		
		public string Value
		{
			get { return mValue; }
			set 
			{ 
				mValue = value;
				changed = true;
			}
		}
		
		public bool Changed
		{
			get { return changed; }
		}
		
		public override string ToString()
		{
			return "Metadata element. Key: "+mKey+"; Value: "+mValue;
		}
		
		public MetadataElement Copy()
		{
			return new MetadataElement(mKey, mValue);
		}
	}
}
